@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Deprecated; # git description: v0.003-2-g8f29f37
+package Dist::Zilla::Plugin::Deprecated; # git description: v0.004-16-g6394d2c
 # ABSTRACT: add metadata to your distribution marking it as deprecated
 # KEYWORDS: plugin metadata module distribution deprecated
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
@@ -38,8 +38,9 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        all => $self->all,
-        modules => [ $self->modules ],
+        all => ( $self->all ? 1 : 0),
+        modules => [ sort $self->modules ],
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -74,7 +75,7 @@ Dist::Zilla::Plugin::Deprecated - add metadata to your distribution marking it a
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -98,48 +99,62 @@ for example in the abstract and the first paragraph of the DESCRIPTION section.
 
 You can also mark a single module (or subset of modules) as deprecated by
 listing them with the C<module> option.  This will add an C<x_deprecated>
-field to the C<provides> section of metadata.
+field to the C<provides> section of metadata.  Note that L<CPAN::Meta::Spec>
+requires you need to populate the rest of C<provides> metadata through some
+other means, such as L<Dist::Zilla::Plugin::MetaProvides::Package>.
 
 =head1 CONFIGURATION OPTIONS
 
 =head2 C<module>
 
+    [Deprecated]
+    module = MyApp::OlderAPI
+
 Identify a specific module to be deprecated. Can be used more than once.
 
 =head2 C<all>
 
+    [Deprecated]
+    all = 1
+
 Not normally needed directly. Mark an entire distribution as deprecated. This
 defaults to true when there are no C<module>s listed, and false otherwise.
 
 =for Pod::Coverage metadata mvp_aliases mvp_multivalue_args
 
-=head1 SUPPORT
+=head1 ACKNOWLEDGEMENTS
 
-=for stopwords irc
+Neil Bowers requested this. :)  And then he
+L<blogged about it|http://neilb.org/2015/01/17/deprecated-metadata.html>.
+
+=head1 SUPPORT
 
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-Deprecated>
 (or L<bug-Dist-Zilla-Plugin-Deprecated@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-Deprecated@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://dzil.org/#mailing-list>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
+
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
-=head1 ACKNOWLEDGEMENTS
-
-Neil Bowers requested this. :)
-
 =head1 AUTHOR
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Karen Etheridge.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTOR
 
 =for stopwords Neil Bowers
 
 Neil Bowers <neil@bowers.com>
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2015 by Karen Etheridge.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
